| Title: | Supporting Data for the blaseRtools Package |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Brad Blaser [aut, cre] (ORCID: <https://orcid.org/0000-0002-3168-5423>) |
| Maintainer: | Brad Blaser <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9013 |
| Built: | 2026-06-03 06:50:23 UTC |
| Source: | https://github.com/blaserlab/blaseRdata |
A precompiled list of mitochondrial and ribosomal gene names to remove.
dr11_remove_genesdr11_remove_genes
A character vector
See data-raw/remove_genes
Ensembl
From TxDb.Drerio.UCSC.danRer11.refGene
dr11_tssdr11_tss
A GRanges object:
see data-raw/tss.R
This is a copy of the Drerio object from BSgenome.Drerio.UCSC.danRer11. It is here for more convenient use with blaseRtools functions and to reduce dependencies.
DrerioDrerio
A BSgenome object:
see data-raw/grcz11_objects.R
UCSC danRer11 genome build
Full Genome Model for humans. Based on GRCh38 genome build.
hg38_grangeshg38_granges
A GRanges object:
see data-raw/hg38_objects.R
http://ftp.ensembl.org/pub/release-104/gff3/homo_sapiens/
Similar to the Human Gene Model "hg38_granges" but with different metadata columns and only with 5', CDS, and 3' UTR ranges. Also has principle isoform data.
hg38_granges_reducedhg38_granges_reduced
A GRanges object:
see data-raw/trace_objects.R
http://ftp.ensembl.org/pub/release-104/gff3/homo_sapiens/
A precompiled list of mitochondrial and ribosomal gene names to remove.
hg38_remove_geneshg38_remove_genes
A character vector
See data-raw/remove_genes
Ensembl
From TxDb.Hsapiens.UCSC.hg38.knownGene
hg38_tsshg38_tss
A GRanges object:
see data-raw/tss.R
This is a copy of the Hsapiens object from BSgenome.Hsapiens.UCSC.hg38. It is here for more convenient use with blaseRtools functions and to reduce dependencies.
HsapiensHsapiens
A BSgenome object:
see data-raw/hg38_objects.R
UCSC hg38 genome build
JASPAR 2020 TF Motif database in character string format. Mostly for internal use.
memememe
A character vector.
see data-raw/meme.R
JASPAR2020_CORE_vertebrates_non-redundant_pfms_jaspar.txt
A precompiled list of mitochondrial and ribosomal gene names to remove.
mm39_remove_genesmm39_remove_genes
A character vector
See data-raw/remove_genes
Ensembl
Gene set metadata for the whole MSIGDB. Most gene sets are known by "STANDARD_NAME". You can filter the gene set list by supplying a named filter list to the bb_extract_msig function. The name of each list element should be one of the column names in this metadata table and the list element contents should be the values to filter for. Filtering works in an additive way, meaning if you supply a filter list with two elements it will extract gene sets passing filters 1 AND 2.
msigdb_geneset_metadatamsigdb_geneset_metadata
A data frame with 32796 rows and 18 variables:
STANDARD_NAMEcharacter
SYSTEMATIC_NAMEcharacter
HISTORICAL_NAMEcharacter
ORGANISMcharacter
PMIDcharacter
AUTHORScharacter
GEOIDcharacter
EXACT_SOURCEcharacter
GENESET_LISTING_URLcharacter
EXTERNAL_DETAILS_URLcharacter
CHIPcharacter
CATEGORY_CODEcharacter
SUB_CATEGORY_CODEcharacter
CONTRIBUTORcharacter
CONTRIBUTOR_ORGcharacter
DESCRIPTION_BRIEFcharacter
DESCRIPTION_FULLcharacter
TAGScharacter
Use with bb_extract_msig
https://www.gsea-msigdb.org/gsea/msigdb/ accessed January 12 2022.
List of MSIGDB gene sets. Most gene sets are commonly known by "STANDARD_NAME". This is a unique value and is provided as the name for each of the elements in this list. If you want to select a single gene set by name you can use the usual R syntax for selecting named elements: msigdb_genesets$<gene set name>. If you want to select by other metadata features you should use bb_extract_msig.
msigdb_genesetsmsigdb_genesets
A list.
Use with bb_extract_msig
https://www.gsea-msigdb.org/gsea/msigdb/ accessed January 12 2022.
Standard bb_qc function output
vig_qc_resvig_qc_res
a list
See blaseRtools scRNAseq Vignette
vignette_cds
A small example CDS for the blaseRtools vignette
vignette_cdsvignette_cds
A cellDataSet object
See blaseRtools scRNAseq Vignette
https://www.10xgenomics.com/resources/datasets/500-human-pbm-cs-3-lt-v-3-1-chromium-controller-3-1-low-6-1-0 and https://www.10xgenomics.com/resources/datasets/500-human-pbm-cs-3-lt-v-3-1-chromium-x-3-1-low-6-1-0
Pseudobulk header, results and qc plots.
vignette_pseudobulk_resvignette_pseudobulk_res
A list of pseudobulk results
See blaseRtools scRNAseq Vignette
Top Markers for the vignette CDS
vignette_top_markersvignette_top_markers
A data frame with 1100 rows and 11 variables:
gene_idcharacter Ensembl gene identifier
gene_short_namecharacter Gene Name
cluster_methodcharacter Clustering Method
cell_groupcharacter Cell Cluster or Partition
marker_scoredouble Composite score of fraction expressing and level of expression.
mean_expressiondouble Mean marker expression
fraction_expressingdouble Fraction expressing
specificitydouble Marker specificity
pseudo_R2double Regression pseudo R squared
marker_test_p_valuedouble Wald test P value
marker_test_q_valuedouble q value
See blaseRtools scRNAseq Vignette
Wordlist from the Grady Parts of Speech database. In order to reuse, 1.) Calculate the md5sum of the object you want to hash, 2.) Take the first 5 or more hex digits and fill them in this expression: as.integer(as.hexmode("<hex digits>") %% 226857) + 1. This will return an integer between 1 and 226857 which is the length of the wordlist hashtable. Then select the word according to the integer/index value using something like: wordlist %>% filter(index == integer) %>% pull(word).
wordhashwordhash
A data frame with 226857 rows and 2 variables:
indexinteger
wordcharacter
see data-raw/wordhash.R for construction
https://www.gutenberg.org/ebooks/3201
This is a granges object containing the full genome model from the zfin database. Based on GRCz11 genome build.
zfin_grangeszfin_granges
A GRanges object:
see data-raw/grcz11_objects.R
https://zfin.org/downloads/zfin_genes.gff3 release April 2018
Similar to the Zebrafish Gene Model but with different metadata columns and only with 5', CDS and 3' UTR ranges. Also has principle isoform data.
zfin_granges_reducedzfin_granges_reduced
A GRanges object:
see data-raw/trace_objects.R
https://zfin.org/downloads/zfin_genes.gff3 release April 2018